==> igniteui-angular-charts-18.2.0.tgz: package/esm5/lib/SeriesRenderManager.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, markType } from "igniteui-angular-core";
/**
 * @hidden
 */
var SeriesRenderManager = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(SeriesRenderManager, _super);
    function SeriesRenderManager() {
        var _this = _super !== null && _super.apply(this, arguments) || this;
        _this.ag = null;
        _this.ah = null;
        _this.m = 0;
        _this.am = null;
        _this.ao = 0;
        _this.k = 0;
        _this.l = 0;
        _this.j = 0;
        _this.i = 0;
        _this.au = 0;
        _this.aq = 0;
        _this.ap = 0;
        _this.ak = null;
        _this.al = null;
        _this.t = 0;
        _this.an = null;
        _this.ar = 0;
        _this.r = 0;
        _this.s = 0;
        _this.q = 0;
        _this.p = 0;
        _this.av = 0;
        _this.at = 0;
        _this.as = 0;
        _this.ai = null;
        _this.aj = null;
        _this.n = 0;
        _this.o = 0;
        _this.f = false;
        _this.e = false;
        _this.ae = null;
        _this.af = null;
        _this.g = 0;
        _this.h = 0;
        _this.b = null;
        _this.d = null;
        return _this;
    }
    SeriesRenderManager.prototype.w = function (a, b, c) {
        this.e = false;
        this.ai = a.vl();
        this.aj = a.vm();
        this.n = 1;
        this.o = a.io();
        this.ae = this.ai;
        this.af = this.aj;
        this.g = this.n;
        this.h = this.o;
        var d = b;
        this.d = null;
        if (d) {
            this.d = this.c();
            this.d.m = 0;
            this.d.q = 0;
            this.d.u = 0;
            this.d.v = 0;
            this.d.x = 0;
            this.d.t = 0;
            this.d.n = 0;
            this.d.r = 0;
            this.d.w = 0;
            this.d.l = 0;
            this.d.p = 0;
            this.d.s = 0;
            if (a.db != null && a.bx != 1) {
                this.d.m = a.db.dl.maxMarkerHighlightingProgress;
                this.d.q = a.db.dl.sumMarkerHighlightingProgress;
                this.d.v = a.db.dl.totalHighWaterMark;
                this.d.u = a.db.dl.totalHighlightingProgress;
            }
            if (a.db != null && a.cp != 1) {
                this.d.n = a.db.dm.maxMarkerHighlightingProgress;
                this.d.r = a.db.dm.sumMarkerHighlightingProgress;
                this.d.x = a.db.dm.totalHighWaterMark;
                this.d.w = a.db.dm.totalHighlightingProgress;
            }
            if (a.db != null && a.co != 1) {
                this.d.l = a.db.dk.maxMarkerHighlightingProgress;
                this.d.p = a.db.dk.sumMarkerHighlightingProgress;
                this.d.t = a.db.dk.totalHighWaterMark;
                this.d.s = a.db.dk.totalHighlightingProgress;
            }
            this.d.a = c;
        }
    };
    SeriesRenderManager.prototype.c = function () {
        return null;
    };
    SeriesRenderManager.prototype.x = function (a, b, c) {
        this.f = false;
        this.ak = a.u9;
        this.al = a.vd;
        this.t = a.ie;
        this.an = a.v2;
        this.ar = a.v3;
        this.r = 0;
        this.s = 0;
        this.q = 1;
        this.p = a.jh;
        this.at = a.v4;
        this.as = a.v4;
        this.av = a.v5;
        this.ag = this.ak;
        this.ah = this.al;
        this.m = this.t;
        this.am = this.an;
        this.ao = this.ar;
        this.k = this.r;
        this.l = this.s;
        this.j = this.q;
        this.i = this.p;
        this.aq = this.at;
        this.ap = this.as;
        this.au = this.av;
        var d = b;
        this.b = null;
        if (d) {
            this.b = this.a();
            this.b.m = 0;
            this.b.q = 0;
            this.b.v = 0;
            this.b.x = 0;
            this.b.t = 0;
            this.b.u = 0;
            this.b.n = 0;
            this.b.r = 0;
            this.b.w = 0;
            this.b.l = 0;
            this.b.p = 0;
            this.b.s = 0;
            if (a.db != null && a.bx != 1) {
                this.b.m = a.db.dl.maxHighlightingProgress;
                this.b.q = a.db.dl.sumHighlightingProgress;
                this.b.v = a.db.dl.totalHighWaterMark;
                this.b.u = a.db.dl.totalHighlightingProgress;
            }
            if (a.db != null && a.cp != 1) {
                this.b.n = a.db.dm.maxHighlightingProgress;
                this.b.r = a.db.dm.sumHighlightingProgress;
                this.b.x = a.db.dm.totalHighWaterMark;
                this.b.w = a.db.dm.totalHighlightingProgress;
            }
            if (a.db != null && a.cp != 1) {
                this.b.l = a.db.dk.maxHighlightingProgress;
                this.b.p = a.db.dk.sumHighlightingProgress;
                this.b.t = a.db.dk.totalHighWaterMark;
                this.b.s = a.db.dk.totalHighlightingProgress;
            }
            this.b.a = c;
        }
    };
    SeriesRenderManager.prototype.a = function () {
        return null;
    };
    SeriesRenderManager.prototype.ad = function (a, b, c, d, e) {
        var f = this.ag;
        if (e) {
            f = this.ah;
        }
        if (c) {
            a._fill = f;
        }
        else {
            if (b) {
                a._stroke = f;
            }
            else {
                a._fill = f;
                a._stroke = this.ah;
            }
            a.ad = this.m;
            a.ai = this.am;
            a.aj = this.ao;
            if (d) {
                a.ac = this.i;
                a.am = this.au;
                a.al = this.aq;
                a.ak = this.ap;
            }
        }
        a._opacity = this.j;
    };
    SeriesRenderManager.prototype.ac = function (a, b) {
        a._opacity = this.g;
        b.itemBrush = this.ae;
        b.thickness = this.h;
        b.actualItemBrush = b.itemBrush;
        b.outline = this.af;
    };
    SeriesRenderManager.prototype.u = function (a, b, c, d, e, f, g, h, i, j, k, l) {
        if (a.bx == 1 && a.cp == 1 && a.co == 1) {
            return;
        }
        this.j = a.ba.a$k(a, b, c, d, this.j, e, f, g, h, i, j, k, l);
        this.ag = a.ba.a$at(a, b, c, d, e, f, g, h, i, j, this.ag, false);
        this.ah = a.ba.a$at(a, b, c, d, e, f, g, h, i, j, this.ah, true);
        this.m = a.ba.a$l(a, b, c, d, this.m);
    };
    SeriesRenderManager.prototype.v = function (a, b, c, d, e, f, g, h, i, j, k) {
        if (!a.el) {
            return;
        }
        if (a.bx == 1 && a.cp == 1 && a.co == 1) {
            return;
        }
        this.g = a.ba.a$k(a, b, c, d, this.g, e, f, g, h, i, j, k, false);
        this.ae = a.ba.a$at(a, b, c, d, e, f, g, h, i, j, this.ae, false);
        this.af = a.ba.a$at(a, b, c, d, e, f, g, h, i, j, this.af, true);
        this.h = a.ba.a$l(a, b, c, d, this.h);
    };
    SeriesRenderManager.prototype.ab = function (a) {
        this.ag = this.ak;
        this.ah = this.al;
        this.m = this.t;
        this.am = this.an;
        this.ao = this.ar;
        this.k = this.r;
        this.l = this.s;
        this.j = this.q;
        var b = this.b;
        b.aa = this.ag;
        b.ab = this.ah;
        b.ae = this.m;
        b.af = this.am;
        b.ag = this.ao;
        b.ac = this.k;
        b.ad = this.l;
        b.o = this.j;
        b.g = this.f;
        b.k = a;
        b.f = false;
    };
    SeriesRenderManager.prototype.z = function (a, b, c, d, e, f, g, h, i) {
        var j = this.b;
        this.ag = j.aa;
        this.ah = j.ab;
        this.m = j.ae;
        this.am = j.af;
        this.ao = j.ag;
        this.k = j.ac;
        this.l = j.ad;
        this.j = j.o;
        if ((f || g || h) && !j.f && !e) {
            this.u(a, b, c, d, j.v, j.v, j.x, j.x, j.t, j.t, j.k, i);
        }
    };
    SeriesRenderManager.prototype.aa = function (a) {
        this.ae = this.ai;
        this.af = this.aj;
        this.g = this.n;
        this.h = this.o;
        var b = this.d;
        b.aa = this.ae;
        b.ab = this.af;
        b.o = this.g;
        b.g = this.e;
        b.k = a;
        b.f = false;
    };
    SeriesRenderManager.prototype.y = function (a, b, c, d, e, f, g, h, i, j, k, l, m, n) {
        var o = this.d;
        this.ae = o.aa;
        this.af = o.ab;
        this.g = o.o;
        if ((f || g || h) && !o.f && !e) {
            this.v(a, b, c, d, i, j, k, l, m, n, o.k);
        }
    };
    SeriesRenderManager.$t = markType(SeriesRenderManager, 'SeriesRenderManager');
    return SeriesRenderManager;
}(Base));
export { SeriesRenderManager };

==> igniteui-angular-charts-20.0.0.tgz: package/esm5/lib/SeriesRenderManager.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, markType } from "igniteui-angular-core";
/**
 * @hidden
 */
var SeriesRenderManager = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(SeriesRenderManager, _super);
    function SeriesRenderManager() {
        var _this = _super !== null && _super.apply(this, arguments) || this;
        _this.ag = null;
        _this.ah = null;
        _this.m = 0;
        _this.am = null;
        _this.ao = 0;
        _this.k = 0;
        _this.l = 0;
        _this.j = 0;
        _this.i = 0;
        _this.au = 0;
        _this.aq = 0;
        _this.ap = 0;
        _this.ak = null;
        _this.al = null;
        _this.t = 0;
        _this.an = null;
        _this.ar = 0;
        _this.r = 0;
        _this.s = 0;
        _this.q = 0;
        _this.p = 0;
        _this.av = 0;
        _this.at = 0;
        _this.as = 0;
        _this.ai = null;
        _this.aj = null;
        _this.n = 0;
        _this.o = 0;
        _this.f = false;
        _this.e = false;
        _this.ae = null;
        _this.af = null;
        _this.g = 0;
        _this.h = 0;
        _this.b = null;
        _this.d = null;
        return _this;
    }
    SeriesRenderManager.prototype.w = function (a, b, c) {
        this.e = false;
        this.ai = a.vq();
        this.aj = a.vr();
        this.n = 1;
        this.o = a.ip();
        this.ae = this.ai;
        this.af = this.aj;
        this.g = this.n;
        this.h = this.o;
        var d = b;
        this.d = null;
        if (d) {
            this.d = this.c();
            this.d.m = 0;
            this.d.q = 0;
            this.d.u = 0;
            this.d.v = 0;
            this.d.x = 0;
            this.d.t = 0;
            this.d.n = 0;
            this.d.r = 0;
            this.d.w = 0;
            this.d.l = 0;
            this.d.p = 0;
            this.d.s = 0;
            if (a.dc != null && a.by != 1) {
                this.d.m = a.dc.dk.maxMarkerHighlightingProgress;
                this.d.q = a.dc.dk.sumMarkerHighlightingProgress;
                this.d.v = a.dc.dk.totalHighWaterMark;
                this.d.u = a.dc.dk.totalHighlightingProgress;
            }
            if (a.dc != null && a.cq != 1) {
                this.d.n = a.dc.dl.maxMarkerHighlightingProgress;
                this.d.r = a.dc.dl.sumMarkerHighlightingProgress;
                this.d.x = a.dc.dl.totalHighWaterMark;
                this.d.w = a.dc.dl.totalHighlightingProgress;
            }
            if (a.dc != null && a.cp != 1) {
                this.d.l = a.dc.dj.maxMarkerHighlightingProgress;
                this.d.p = a.dc.dj.sumMarkerHighlightingProgress;
                this.d.t = a.dc.dj.totalHighWaterMark;
                this.d.s = a.dc.dj.totalHighlightingProgress;
            }
            this.d.a = c;
        }
    };
    SeriesRenderManager.prototype.c = function () {
        return null;
    };
    SeriesRenderManager.prototype.x = function (a, b, c) {
        this.f = false;
        this.ak = a.ve;
        this.al = a.vi;
        this.t = a.ig;
        this.an = a.v7;
        this.ar = a.v8;
        this.r = 0;
        this.s = 0;
        this.q = 1;
        this.p = a.ji;
        this.at = a.v9;
        this.as = a.v9;
        this.av = a.wa;
        this.ag = this.ak;
        this.ah = this.al;
        this.m = this.t;
        this.am = this.an;
        this.ao = this.ar;
        this.k = this.r;
        this.l = this.s;
        this.j = this.q;
        this.i = this.p;
        this.aq = this.at;
        this.ap = this.as;
        this.au = this.av;
        var d = b;
        this.b = null;
        if (d) {
            this.b = this.a();
            this.b.m = 0;
            this.b.q = 0;
            this.b.v = 0;
            this.b.x = 0;
            this.b.t = 0;
            this.b.u = 0;
            this.b.n = 0;
            this.b.r = 0;
            this.b.w = 0;
            this.b.l = 0;
            this.b.p = 0;
            this.b.s = 0;
            if (a.dc != null && a.by != 1) {
                this.b.m = a.dc.dk.maxHighlightingProgress;
                this.b.q = a.dc.dk.sumHighlightingProgress;
                this.b.v = a.dc.dk.totalHighWaterMark;
                this.b.u = a.dc.dk.totalHighlightingProgress;
            }
            if (a.dc != null && a.cq != 1) {
                this.b.n = a.dc.dl.maxHighlightingProgress;
                this.b.r = a.dc.dl.sumHighlightingProgress;
                this.b.x = a.dc.dl.totalHighWaterMark;
                this.b.w = a.dc.dl.totalHighlightingProgress;
            }
            if (a.dc != null && a.cq != 1) {
                this.b.l = a.dc.dj.maxHighlightingProgress;
                this.b.p = a.dc.dj.sumHighlightingProgress;
                this.b.t = a.dc.dj.totalHighWaterMark;
                this.b.s = a.dc.dj.totalHighlightingProgress;
            }
            this.b.a = c;
        }
    };
    SeriesRenderManager.prototype.a = function () {
        return null;
    };
    SeriesRenderManager.prototype.ad = function (a, b, c, d, e) {
        var f = this.ag;
        if (e) {
            f = this.ah;
        }
        if (c) {
            a._fill = f;
        }
        else {
            if (b) {
                a._stroke = f;
            }
            else {
                a._fill = f;
                a._stroke = this.ah;
            }
            a.ad = this.m;
            a.ai = this.am;
            a.aj = this.ao;
            if (d) {
                a.ac = this.i;
                a.am = this.au;
                a.al = this.aq;
                a.ak = this.ap;
            }
        }
        a._opacity = this.j;
    };
    SeriesRenderManager.prototype.ac = function (a, b) {
        a._opacity = this.g;
        b.itemBrush = this.ae;
        b.thickness = this.h;
        b.actualItemBrush = b.itemBrush;
        b.outline = this.af;
    };
    SeriesRenderManager.prototype.u = function (a, b, c, d, e, f, g, h, i, j, k, l) {
        if (a.by == 1 && a.cq == 1 && a.cp == 1) {
            return;
        }
        this.j = a.ba.a$k(a, b, c, d, this.j, e, f, g, h, i, j, k, l);
        this.ag = a.ba.a$at(a, b, c, d, e, f, g, h, i, j, this.ag, false);
        this.ah = a.ba.a$at(a, b, c, d, e, f, g, h, i, j, this.ah, true);
        this.m = a.ba.a$l(a, b, c, d, this.m);
    };
    SeriesRenderManager.prototype.v = function (a, b, c, d, e, f, g, h, i, j, k) {
        if (!a.en) {
            return;
        }
        if (a.by == 1 && a.cq == 1 && a.cp == 1) {
            return;
        }
        this.g = a.ba.a$k(a, b, c, d, this.g, e, f, g, h, i, j, k, false);
        this.ae = a.ba.a$at(a, b, c, d, e, f, g, h, i, j, this.ae, false);
        this.af = a.ba.a$at(a, b, c, d, e, f, g, h, i, j, this.af, true);
        this.h = a.ba.a$l(a, b, c, d, this.h);
    };
    SeriesRenderManager.prototype.ab = function (a) {
        this.ag = this.ak;
        this.ah = this.al;
        this.m = this.t;
        this.am = this.an;
        this.ao = this.ar;
        this.k = this.r;
        this.l = this.s;
        this.j = this.q;
        var b = this.b;
        b.aa = this.ag;
        b.ab = this.ah;
        b.ae = this.m;
        b.af = this.am;
        b.ag = this.ao;
        b.ac = this.k;
        b.ad = this.l;
        b.o = this.j;
        b.g = this.f;
        b.k = a;
        b.f = false;
    };
    SeriesRenderManager.prototype.z = function (a, b, c, d, e, f, g, h, i) {
        var j = this.b;
        this.ag = j.aa;
        this.ah = j.ab;
        this.m = j.ae;
        this.am = j.af;
        this.ao = j.ag;
        this.k = j.ac;
        this.l = j.ad;
        this.j = j.o;
        if ((f || g || h) && !j.f && !e) {
            this.u(a, b, c, d, j.v, j.v, j.x, j.x, j.t, j.t, j.k, i);
        }
    };
    SeriesRenderManager.prototype.aa = function (a) {
        this.ae = this.ai;
        this.af = this.aj;
        this.g = this.n;
        this.h = this.o;
        var b = this.d;
        b.aa = this.ae;
        b.ab = this.af;
        b.o = this.g;
        b.g = this.e;
        b.k = a;
        b.f = false;
    };
    SeriesRenderManager.prototype.y = function (a, b, c, d, e, f, g, h, i, j, k, l, m, n) {
        var o = this.d;
        this.ae = o.aa;
        this.af = o.ab;
        this.g = o.o;
        if ((f || g || h) && !o.f && !e) {
            this.v(a, b, c, d, i, j, k, l, m, n, o.k);
        }
    };
    SeriesRenderManager.$t = markType(SeriesRenderManager, 'SeriesRenderManager');
    return SeriesRenderManager;
}(Base));
export { SeriesRenderManager };
